@@ -138,7 +138,7 @@ def get_current_app_list(detail=False) -> list:
         cmd_text += " /v"
 
     _res = execute_cmd(cmd_text, encoding=None, level=None)
-    out_decode, encoding = bytes_to_str(_res.stdout)
+    out_decode = bytes_to_str(_res.stdout)
 
     _app_list = []
     for _line in out_decode.strip().split("\n"):
